@@ -21,6 +21,7 @@
 #include <glib/gi18n.h>
 
 #include <errno.h>
+#include <locale.h>
 #include <limits.h>
 #include <stdlib.h>
 
@@ -266,7 +267,7 @@ read_password_tty (void)
 
 	password = getpass ("Password: ");
 	return secret_value_new_full (password, -1, "text/plain",
-	                              (GDestroyNotify)secret_password_clear);
+	                              (GDestroyNotify)secret_password_wipe);
 }
 
 static int
@@ -336,6 +337,14 @@ main (int argc,
 {
 	SecretToolAction action;
 
+	setlocale (LC_ALL, "");
+
+#ifdef ENABLE_NLS
+	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
+#endif
+
 	g_type_init ();
 
 	if (argc < 2)
